<?php

namespace EwKit\Theme;

use EwKit\Theme\Interfaces\ViewModel;
use Infomaker\Everyware\Base\ArticleBodyParser;
use Infomaker\Everyware\Base\Menus;
use Infomaker\Everyware\Base\Models\Post;
use Infomaker\Everyware\Support\GenericPropertyObject;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;
use OcArticle;

/**
 * Class ArticlePageTemplate
 * @package EwKit\Theme
 */
class ArticlePageTemplate implements ViewModel
{
    /**
     * @var NewsMLArticle
     */
    private $article;

    public function __construct(NewsMLArticle $article)
    {
        $this->article = $article;
    }

    public function getViewData(): array
    {
        $articleBody = $this->article->getParsedBody();

        $main_menu = Menus::getFromLocation('main-menu');

        return array_replace($this->article->toArray(), [
            'menu' => $main_menu ? $main_menu->items() : [],
            'body' => implode($articleBody->generateContent(new ArticleBodyPresentation($this->article)))
        ]);

    }

    public static function createFromPost(Post $post)
    {
        $uuid = $post->getMeta('oc_uuid');

        $provider = OpenContentProvider::setup();
        $provider->setPropertyMap('Article');
        $article = $provider->getObject($uuid);

        if ($article instanceof OcArticle) {
            return new static(NewsMLArticle::createFromOcArticle($article));
        }

        return new static(new NewsMLArticle($article));
    }
}
