<?php

namespace EwKit\Theme;

use EwKit\Theme\Interfaces\ViewModel;
use Infomaker\Everyware\NewsML\Objects\ImageItem;
use Infomaker\Everyware\Support\NewRelicLog;
use Infomaker\Imengine\CropData\AutoCropData;
use Infomaker\Imengine\CropData\CropResizeData;
use Infomaker\Imengine\Helpers\ImengineHelper;
use Infomaker\Imengine\Imengine;
use RuntimeException;

class Image implements ViewModel
{

    /**
     * @var ImageItem
     */
    private $image;

    public function __construct(ImageItem $image)
    {
        $this->image = $image;
    }

    public function getRatioUrl($width, $ratio = '16:9'): string
    {
        try {

            if ($this->image->hasCropForRatio($ratio)) {
                $crop = $this->image->getCropForRatio($ratio);

                $crop_handler = new CropResizeData($crop['width'], $crop['height']);

                $crop_handler
                    ->setCropX($crop['x'])
                    ->setCropY($crop['y'])
                    ->setWidth($width)
                    ->setHeight(ImengineHelper::calculateRatioHeight($width, $ratio));

                return Imengine::cropResize($crop_handler)->fromUuid($this->image->uuid);
            }

            if ($this->image->hasOriginalSizes()) {
                $crop_handler = new AutoCropData($this->image->width, $this->image->height, $width);

                $crop_handler->setRatio($ratio);

                return Imengine::autoCrop($crop_handler)->fromUuid($this->image->uuid);
            }

            return Imengine::ratio($width, $ratio)->fromUuid($this->image->uuid);

        } catch (RuntimeException $e) {
            NewRelicLog::error('Failed to fetch imengine url', $e);
        }

        return '';
    }

    private function createSrcset(array $sizes): string
    {
        $srcset = [];
        foreach ($sizes as $size) {
            if (is_int($size)) {
                $srcset[] = $this->getRatioUrl($size) . " {$size}w";
            }
        }

        return implode(',', $srcset);
    }

    public function getViewData(): array
    {
        return array_replace($this->image->toArray(), [
            'authors' => $this->image->get('author'),
            'src' => $this->getRatioUrl(1200),
            'srcset' => $this->createSrcset([300, 600, 900, 1200, 1500])
        ]);
    }
}
