<?php declare(strict_types=1);

namespace EwKit\Theme\Services;

use App\Interfaces\ThemeStartup;
use EwKit\Theme\Interfaces\ThemeServiceStartup;
use Infomaker\Everyware\NewsML\NewsMLTransformerManager;
use Infomaker\Everyware\NewsML\Parsers\ContentPartParser;
use Infomaker\Everyware\NewsML\Parsers\ElementParser;
use Infomaker\Everyware\NewsML\Parsers\HtmlEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\ImageGalleryParser;
use Infomaker\Everyware\NewsML\Parsers\ImageParser;
use Infomaker\Everyware\NewsML\Parsers\LinkObjectParser;
use Infomaker\Everyware\NewsML\Parsers\PdfParser;
use Infomaker\Everyware\NewsML\Parsers\ReviewParser;
use Infomaker\Everyware\NewsML\Parsers\SocialEmbedParser;
use Infomaker\Everyware\NewsML\Parsers\TableParser;
use Infomaker\Everyware\NewsML\Parsers\TeaserParser;
use Infomaker\Everyware\NewsML\Parsers\YoutubeParser;

/**
 * Class ArticleParserService
 * @package EwKit\Theme\Services
 */
class NewsMLParserServiceStartup implements ThemeServiceStartup
{
    public function setup(): void
    {
        $objectParsers = [
            SocialEmbedParser::OBJECT_TYPE => new SocialEmbedParser(),
            TeaserParser::OBJECT_TYPE => new TeaserParser(),
            ImageParser::OBJECT_TYPE => new ImageParser(),
            ImageGalleryParser::OBJECT_TYPE => new ImageGalleryParser(),
            TableParser::OBJECT_TYPE => new TableParser(),
            ContentPartParser::OBJECT_TYPE => new ContentPartParser(new ElementParser()),
            ReviewParser::OBJECT_TYPE => new ReviewParser(new ElementParser()),
            LinkObjectParser::OBJECT_TYPE => new LinkObjectParser(),
            HtmlEmbedParser::OBJECT_TYPE => new HtmlEmbedParser(),
            PdfParser::OBJECT_TYPE => new PdfParser(),
            YoutubeParser::OBJECT_TYPE => new YoutubeParser()
        ];

        foreach ($objectParsers as $type => $parser) {
            NewsMLTransformerManager::registerObjectParser($type, $parser);
        }
    }
}
