<?php declare(strict_types=1);

namespace EwKit\Theme\Services;

use EwKit\Theme\AssetsHelper;
use EwKit\Theme\Interfaces\ThemeServiceStartup;

/**
 * Class ScriptsServiceStartup
 * @package EwKit\Theme\Services
 */
class ScriptsServiceStartup implements ThemeServiceStartup
{

    /**
     * @var string
     */
    private $prefix;

    private $scriptVersion;

    public function __construct(string $prefix, $scriptVersion = false)
    {
        $this->prefix = $prefix;
        $this->scriptVersion = $scriptVersion;
    }

    public function setup(): void
    {
        add_action('admin_enqueue_scripts', [&$this, 'enqueueAdminScripts']);
        add_action('wp_enqueue_scripts', [&$this, 'enqueueScripts']);
    }

    public function enqueueScripts(): void
    {
        // Remove jquery
        wp_deregister_script('jquery');

        // Remove the bootstrap version added by Everyboard
        wp_deregister_style('bootstrap-css');
        wp_deregister_script('bootstrap-js');
        wp_deregister_style('wp-core-ui');

        wp_enqueue_style("{$this->prefix}-style", AssetsHelper::getStyleUrl('style'), [], $this->scriptVersion);
        wp_enqueue_script("{$this->prefix}-head-js", AssetsHelper::getScriptUrl('head'), [], $this->scriptVersion);
        wp_enqueue_script("{$this->prefix}-body-js", AssetsHelper::getScriptUrl('body'), [], $this->scriptVersion, true);

        if (is_single()) {
            wp_enqueue_script("{$this->prefix}-article-js", AssetsHelper::getScriptUrl('article'), ["{$this->prefix}-body-js"],
                $this->scriptVersion, true);
        }

        wp_localize_script("{$this->prefix}-body-js", 'infomaker', [
            'ajaxurl' => site_url('/ajax.php'),
        ]);
    }

    public function enqueueAdminScripts(): void
    {
        wp_enqueue_style("{$this->prefix}-admin-style", AssetsHelper::getStyleUrl('admin'), [], $this->scriptVersion);
        wp_enqueue_script("{$this->prefix}-admin-js", AssetsHelper::getScriptUrl('admin'), ['jquery'], $this->scriptVersion,
            true);
    }
}
