<?php declare(strict_types=1);

namespace EwKit\Theme\Services;

use EwKit\Theme\Interfaces\ThemeServiceStartup;
use Infomaker\Everyware\Base\Sidebars;

/**
 * Class SidebarServiceStartup
 * @package EwKit\Theme\Services
 */
class SidebarServiceStartup implements ThemeServiceStartup
{
    /**
     * @var array
     */
    private $registeredSidebars;

    public function registerSidebar(string $id, array $options): void
    {
        $this->registeredSidebars[$id] = $options;
    }

    public function registerSidebars(array $sidebars): void
    {
        foreach ($sidebars as $id => $options) {
            $this->registerSidebar($id, $options);
        }
    }

    public function setup(): void
    {
        $this->registerSidebars([
            'ew-before-footer' => [
                'name' => __('Before footer', 'ewkit'),
                'description' => __('Container that is rendered just before the page footer.', 'ewkit'),
                'before_widget' => '<div class="footer-container__widget">',
                'after_widget' => '</div>',
            ],
            'ew-after-footer' => [
                'name' => __('After footer', 'ewkit'),
                'description' => __('Container that is rendered just after the page footer.', 'ewkit'),
                'before_widget' => '<div class="footer-container__widget">',
                'after_widget' => '</div>',
            ]
        ]);

        foreach ($this->registeredSidebars as $id => $sidebar) {
            Sidebars::register($id, $sidebar);
        }
    }
}
