const merge = require('webpack-merge');
const UglifyJsPlugin = require("uglifyjs-webpack-plugin");
const OptimizeCSSAssetsPlugin = require("optimize-css-assets-webpack-plugin");
const commonConfig = require('./webpack.common.js');
const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin;
/**
 * This is the configuration for the prod environment.
 * If you wish to change how webpack operates in prod do it here.
 * Output and input paths should still be configurated in webpack.common.js
 */
const prodConfig = {
       
    devtool: 'source-map',
    mode: 'production',
    optimization: {
        minimizer: [
            new UglifyJsPlugin({
                cache: true,
                parallel: true,
                sourceMap: true, // set to true if you want JS source maps
                uglifyOptions: {
                    output: {
                        comments: false,
                    },
                    compress: {
                        dead_code: true,
                        inline: false,
                    }
                }
            }),
            //Optimize and minify the css.
            //Map:inline is required to retain source maps, cssnano is the preprocessor used by default.
            new OptimizeCSSAssetsPlugin({
                cssProcessorOptions: {
                    map: {
                        inline: false,
                        annotation: true
                    }
                }
            })
        ]
    },
    plugins: [
        //Adds a visual graph off all the compiled files.
        new BundleAnalyzerPlugin()
    ],
};

module.exports = env => {
    return merge(commonConfig(env), prodConfig);
}

